Access to the finest wines at attractive prices | Lot18
Description: Access to the finest wines at attractive prices.
Keywords: wine, wine shop, wine clubs, wine club, top rated, top selling, wine basics, top, rated, champagne, california, region, varietal, cabernet, merlot, pinot

[ { "label": "Home", "url": "/" }, { "label": "Collection", "url": "/boutiques" } ]
[ { "label": "Account Basics", "url": "/account" }, { "label": "Order History", "url": "/account/orders" }, { "label": "Address Management", "url": "/account/addresses" }, { "label": "Credit Card Management", "url": "/account/credit_cards" }, { "label": "My Lot18 Credit", "url": "/account/credit" }, { "label": "Preferences", "url": "/account/preferences" }, { "label": "Logout", "url": "/logout" } ]
Products Account NJ
Lot18 Home
Log in Register

- # Login

- # Register

# Log In

Please enter the email address and password you used when creating your account for Lot18, Tasting Room or Forbes Wine Club.

Forgot password?

# Forgot your password?

Enter your email address below.

Back to log in.

# Register

Register now for access to the best deals on some of the world's greatest wines. Membership is FREE and allows for fast, easy checkout and order tracking, as well as safe, secure storage of your billing and shipping information.

Have a gift card or voucher?
Yes, I have a gift card.
Yes, I have a voucher.

Loading...

### About Lot18

### Customer Support

### Connect

1-855-MYLOT18
1-855-MYLOT18
2 Clark Place, Mahopac, NY 10541
ALL ALCOHOLIC BEVERAGES PURCHASED FROM LOT18 ARE SOLD IN THE STATE OF CALIFORNIA AND TITLE PASSES TO THE BUYER IN CALIFORNIA. Lot18 makes no representation to the legal rights of anyone to ship or import alcoholic beverages into any state outside of California. The buyer is solely responsible for the shipment of alcoholic beverage products. By placing an order with Lot18, buyer authorizes Lot18 to act on buyer’s behalf to engage a common carrier to deliver buyer’s order.